// Copyright Epic Games, Inc. All Rights Reserved.

using System.IO;
using UnrealBuildTool;

public class SkyPortal : ModuleRules
{
    public SkyPortal(ReadOnlyTargetRules Target) : base(Target)
    {
        PCHUsage = ModuleRules.PCHUsageMode.UseExplicitOrSharedPCHs;
        bEnableUndefinedIdentifierWarnings = false;
        CppStandard = CppStandardVersion.Cpp17;

        IsRedistributableOverride = true; ;
        bLegalToDistributeObjectCode = true;
        bPrecompile = true;
        PrecompileForTargets = PrecompileTargetsType.Any;

        if (Target.Platform == UnrealTargetPlatform.Linux)
        {
            PublicIncludePaths.AddRange(new[] {
                "/usr/include",
                "/usr/include/x86_64-linux-gnu"
            });
            PublicSystemLibraries.Add("udev"); // Link with libudev on Linux
            PublicSystemLibraryPaths.AddRange(new[] {
                "/usr/lib",
                "/usr/lib/x86_64-linux-gnu",
                "/usr/lib/aarch64-linux-gnu",
                "/usr/local/lib",
                "/usr/local/lib/x86_64-linux-gnu",
                "/usr/local/lib/aarch64-linux-gnu"
            });
        }
        else if (Target.Platform == UnrealTargetPlatform.Win64)
        {
            PublicAdditionalLibraries.Add("hid.lib");  // Use Windows HID library
        }

        string HIDAPIPath = Path.Combine(ModuleDirectory, "../../ThirdParty/hidapi/include");


        PublicIncludePaths.AddRange(
            new string[] {
                HIDAPIPath,
    }
            );


        PrivateIncludePaths.AddRange(
            new string[] {
				// ... add other private include paths required here ...
			}
            );


        PublicDependencyModuleNames.AddRange(
            new string[]
            {
                "Core",
                "CoreUObject",
                "Engine"
				// ... add other public dependencies that you statically link with here ...
			}
            );


        PrivateDependencyModuleNames.AddRange(
            new string[]
            {
                "CoreUObject",
                "Engine",
                "Slate",
                "SlateCore",
				// ... add private dependencies that you statically link with here ...	
			}
            );


        DynamicallyLoadedModuleNames.AddRange(
            new string[]
            {
				// ... add any modules that your module loads dynamically here ...
			}
            );
    }
}
